/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xee,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x60,0x6,0x25,0xf,0x0,0x96,0x92,0x38,0x1e,0x40,0x73,0x73,
  0x33,0x8d,0xa4,0xad,0xdd,0x3d,0x43,0x69,0x6b,0xae,0xa1,0xa7,0xcf,0xa1,0x18,0x2f,
  0x45,0x91,0xfe,0x56,0xcb,0x6e,0x93,0x8e,0xb,0x76,0x2e,0x31,0x0,0x30,0x0,0x2e,
  0x0,0xf,0x24,0x8,0xc,0xa0,0xcd,0x97,0x12,0x31,0xcf,0xc4,0xb3,0xd6,0x6a,0xcd,
  0x22,0x40,0xf2,0x97,0xcb,0xf8,0x50,0xec,0x34,0x1,0xf9,0xcd,0xb7,0x2,0xbc,0xa9,
  0x5b,0xc0,0xdb,0xf8,0x33,0x8,0x5e,0xde,0x3e,0x76,0xfa,0x91,0x28,0x11,0x74,0x9e,
  0xc,0xba,0x6d,0x21,0x4d,0xed,0x82,0x57,0x9f,0xc5,0x4d,0x8c,0x64,0x3,0x31,0x11,
  0x79,0xb6,0x3c,0x1b,0x2f,0x3a,0xd3,0x44,0xe4,0x4e,0x19,0x87,0xbc,0xc7,0x46,0xbf,
  0xb1,0xad,0xb4,0xad,0x94,0x91,0x99,0xb4,0x23,0x6f,0x55,0x92,0x7f,0x70,0x5b,0xdd,
  0xbe,0x42,0x67,0xcb,0x8,0x79,0xa6,0x70,0xd1,0x2a,0x56,0x27,0x9b,0x5a,0xce,0x1f,
  0xdc,0xe6,0x29,0x4d,0xeb,0xf4,0x75,0x98,0x1e,0x56,0x6b,0x3b,0xff,0x70,0x4a,0xd,
  0xab,0x41,0xd6,0x3d,0xbc,0x82,0xee,0xdc,0x2b,0x89,0x50,0x32,0xdf,0xa5,0xc6,0x4,
  0xcf,0x93,0x99,0x76,0x3e,0xfa,0x1,0x51,0xec,0x3d,0x9e,0xc9,0x33,0x7b,0xaa,0xe8,
  0x19,0x5f,0xb4,0x28,0xde,0x9e,0x4c,0xdb,0x90,0xd1,0xde,0xb6,0x42,0x4e,0x2c,0xf7,
  0x8e,0xa6,0x42,0xa7,0xe5,0x23,0x94,0xe,0x9,0x2f,0x8f,0x6f,0xd1,0x45,0x7e,0xa8,
  0x91,0xd2,0x4,0x24,0x34,0xe2,0x42,0xda,0x33,0x30,0x42,0xe2,0xb0,0x93,0x3c,0x22,
  0x58,0x64,0x8e,0x61,0xa8,0x98,0xc0,0x40,0xa5,0x10,0x36,0x14,0x4e,0x34,0xa2,0x6c,
  0x87,0x31,0xd1,0x79,0x55,0xfd,0x8,0xc8,0xf1,0x34,0xb9,0x19,0x2f,0xd6,0x8a,0x60,
  0x72,0x16,0xd0,0x37,0xcf,0x5f,0x65,0x41,0x20,0x78,0x63,0x9b,0x92,0x93,0xaf,0x7d,
  0xb4,0x8c,0xf5,0x93,0x79,0x76,0x4b,0xb3,0xba,0xfc,0xb6,0x97,0xcd,0xa1,0x61,0x18,
  0xc8,0x7e,0xe5,0xaa,0x5e,0xd6,0x9e,0x10,0xef,0xa0,0x82,0x25,0x18,0x63,0x5d,0xac,
  0xb8,0x9,0x7,0x79,0xfe,0x86,0xc2,0xa9,0xa0,0x17,0x19,0x3f,0x13,0x7d,0x9,0x3a,
  0x76,0x88,0xac,0xbe,0xae,0x65,0xd7,0x86,0x51,0x46,0xe2,0x82,0x47,0x24,0x82,0x58,
  0x57,0x77,0x2e,0xe8,0xf2,0xe2,0x6f,0x55,0xf9,0xb8,0x26,0xfc,0x13,0x77,0x83,0x95,
  0xcd,0x19,0x3b,0xe6,0x85,0x52,0xa7,0x3b,0xf0,0xfb,0xb8,0x23,0x83,0xc4,0xe2,0x4c,
  0x5,0xb6,0xae,0x73,0x82,0xd3,0x86,0x3a,0x20,0x1,0x3d,0xef,0x7b,0x5,0xda,0xb4,
  0x12,0x5f,0x7b,0x31,0xf,0x85,0x96,0x9e,0x27,0x3c,0xd3,0xe9,0xd3,0xdf,0x4a,0x90,
  0xaa,0x26,0x70,0xd0,0x1,0x5,0x69,0x8d,0x12,0x60,0xb3,0xa5,0x82,0x89,0x6f,0xb0,
  0x6f,0x50,0x62,0x99,0xa3,0x93,0x97,0x54,0x3e,0xb2,0xda,0x30,0x75,0xa0,0xe0,0x93,
  0xde,0x8,0xaa,0xef,0xd2,0x42,0x35,0x8e,0x95,0x13,0x95,0xc2,0x92,0xd8,0xc6,0x82,
  0xae,0xc,0x17,0x88,0x3b,0x8,0xd4,0x8c,0xb7,0x4a,0x85,0x4b,0x3,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // IVModule
  0x0,0x8,
  0xb,0x45,0xb5,0xe5,
  0x0,0x49,
  0x0,0x56,0x0,0x4d,0x0,0x6f,0x0,0x64,0x0,0x75,0x0,0x6c,0x0,0x65,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x62,0xef,0x6f,0xb0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x62,0xef,0x6f,0xb0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x62,0xef,0x6f,0xb0,
  // :/qt/qml/IVModule
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0xa0,0x62,0xef,0x6f,0xb0,
  // :/qt/qml/IVModule/qmldir
  0x0,0x0,0x0,0x2c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x62,0xef,0x6f,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_IVModule)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_IVModule)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_IVModule)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_IVModule)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_IVModule)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_IVModule)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
