#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_IVModule_qml_main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_FullImageView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageAnimation_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageViewer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_MainStack_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_NavigationWidget_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_OpenImageWidget_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ReName_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_SFadeInOut_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_SliderShow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ThumbnailListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ViewRightMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ViewTopTitle_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_Dialog_RemoveDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_BaseImageDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_DamagedImageDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_DynamicImageDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_MultiImageDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_NonexistImageDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_NormalImageDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_SvgImageDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ImageDelegate_ViewDelegateLoader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_InformationDialog_ElideLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_InformationDialog_InformationDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_InformationDialog_PropertyActionItemDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_InformationDialog_PropertyItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_InformationDialog_PropertyItemDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ThumbnailDelegate_BaseThumbnailDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ThumbnailDelegate_MultiThumnailDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ThumbnailDelegate_NormalThumbnailDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_ThumbnailDelegate_ThumbnailImage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_Utils_FloatingNotice_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_Utils_ImageInputHandler_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_IVModule_qml_Utils_RightMenuItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/main.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/FullImageView.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_FullImageView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageAnimation.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageAnimation_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageViewer.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageViewer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/MainStack.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_MainStack_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/NavigationWidget.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_NavigationWidget_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/OpenImageWidget.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_OpenImageWidget_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ReName.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ReName_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/SFadeInOut.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_SFadeInOut_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/SliderShow.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_SliderShow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ThumbnailListView.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ThumbnailListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ViewRightMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ViewRightMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ViewTopTitle.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ViewTopTitle_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/Dialog/RemoveDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_Dialog_RemoveDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/BaseImageDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_BaseImageDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/DamagedImageDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_DamagedImageDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/DynamicImageDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_DynamicImageDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/MultiImageDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_MultiImageDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/NonexistImageDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_NonexistImageDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/NormalImageDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_NormalImageDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/SvgImageDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_SvgImageDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ImageDelegate/ViewDelegateLoader.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ImageDelegate_ViewDelegateLoader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/InformationDialog/ElideLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_InformationDialog_ElideLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/InformationDialog/InformationDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_InformationDialog_InformationDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/InformationDialog/PropertyActionItemDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_InformationDialog_PropertyActionItemDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/InformationDialog/PropertyItem.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_InformationDialog_PropertyItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/InformationDialog/PropertyItemDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_InformationDialog_PropertyItemDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ThumbnailDelegate/BaseThumbnailDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ThumbnailDelegate_BaseThumbnailDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ThumbnailDelegate/MultiThumnailDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ThumbnailDelegate_MultiThumnailDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ThumbnailDelegate/NormalThumbnailDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ThumbnailDelegate_NormalThumbnailDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/ThumbnailDelegate/ThumbnailImage.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_ThumbnailDelegate_ThumbnailImage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/Utils/FloatingNotice.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_Utils_FloatingNotice_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/Utils/ImageInputHandler.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_Utils_ImageInputHandler_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/IVModule/qml/Utils/RightMenuItem.qml"), &QmlCacheGeneratedCode::_qt_qml_IVModule_qml_Utils_RightMenuItem_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_deepin_image_viewer)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_deepin_image_viewer))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_deepin_image_viewer)() {
    return 1;
}
